#
# spec file for package modello
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           modello
Version:        2.1.2
Release:        2.2
Summary:        Modello Data Model toolkit
License:        Apache-2.0 AND MIT
Group:          Development/Libraries/Java
URL:            https://codehaus-plexus.github.io/modello
Source0:        https://repo1.maven.org/maven2/org/codehaus/%{name}/%{name}/%{version}/%{name}-%{version}-source-release.zip
Source1:        https://www.apache.org/licenses/LICENSE-2.0.txt
Source100:      %{name}-build.tar.xz
Patch0:         modello-cli-domasxpp3.patch
Patch1:         0001-Revert-Switch-to-codehaus-plexus-build-api-1.2.0-345.patch
BuildRequires:  ant
BuildRequires:  aopalliance
BuildRequires:  atinject
BuildRequires:  fdupes
BuildRequires:  google-guice
BuildRequires:  guava
BuildRequires:  javapackages-local >= 6
BuildRequires:  jsoup
BuildRequires:  plexus-build-api
BuildRequires:  plexus-classworlds
BuildRequires:  plexus-containers-component-annotations
BuildRequires:  plexus-metadata-generator
BuildRequires:  plexus-utils
BuildRequires:  sisu-plexus
BuildRequires:  unzip
Requires:       aopalliance
Requires:       atinject
Requires:       google-guice
Requires:       guava
Requires:       javapackages-tools
Requires:       plexus-build-api
Requires:       plexus-classworlds
Requires:       plexus-containers-component-annotations
Requires:       plexus-utils
Requires:       sisu-inject
Requires:       sisu-plexus
BuildArch:      noarch

%description
Modello is a Data Model toolkit in use by the Apache Maven Project.

Modello is a framework for code generation from a simple model.
Modello generates code from a simple model format based on a plugin
architecture, various types of code and descriptors can be generated
from the single model, including Java POJOs, XML
marshallers/unmarshallers, XSD and documentation.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Libraries/Java

%description javadoc
API documentation for %{name}.

%prep
%setup -q -a100
%patch0 -p1
%patch1 -p1
cp -p %{SOURCE1} LICENSE

%pom_remove_plugin :maven-site-plugin
%pom_remove_plugin :maven-enforcer-plugin

%pom_remove_dep :plexus-xml modello-core
%pom_remove_dep :sisu-guice modello-core
%pom_add_dep com.google.inject:guice modello-core

%pom_remove_dep :jackson-bom

%pom_disable_module modello-plugin-jackson modello-plugins
%pom_disable_module modello-plugin-jsonschema modello-plugins
%pom_disable_module modello-plugin-snakeyaml modello-plugins
%pom_disable_module modello-plugin-velocity modello-plugins
%pom_remove_dep :modello-plugin-jackson modello-maven-plugin
%pom_remove_dep :modello-plugin-jsonschema modello-maven-plugin
%pom_remove_dep :modello-plugin-snakeyaml modello-maven-plugin
%pom_remove_dep :modello-plugin-velocity modello-maven-plugin

rm -f modello-maven-plugin/src/main/java/org/codehaus/modello/maven/ModelloVelocityMojo.java

%pom_disable_module modello-test

%build
mkdir -p lib
build-jar-repository -s lib \
    aopalliance \
    atinject \
    commons-cli \
    guava/guava \
    guice/google-guice \
    jdom2/jdom2 \
    jsoup \
    objectweb-asm/asm \
    org.eclipse.sisu.inject \
    org.eclipse.sisu.plexus \
    plexus/classworlds \
    plexus/cli \
    plexus/plexus-build-api \
    plexus/utils \
    plexus-containers/plexus-component-annotations \
    plexus-metadata-generator \
    qdox

%{ant} \
  -Dtest.skip=true \
  package javadoc

%install
# jars
install -dm 0755 %{buildroot}%{_javadir}/%{name}

for i in core; do
  install -pm 0644 %{name}-${i}/target/%{name}-${i}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}-${i}.jar
done

for i in converters dom4j java jdom sax stax xdoc xml xpp3 xsd; do
  install -pm 0644 %{name}-plugins/%{name}-plugin-${i}/target/%{name}-plugin-${i}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}-plugin-${i}.jar
done

# poms
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}

for i in core; do
  %{mvn_install_pom} %{name}-${i}/pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{name}-${i}.pom
  %add_maven_depmap %{name}/%{name}-${i}.pom %{name}/%{name}-${i}.jar
done

for i in converters dom4j java jdom sax stax xdoc xml xpp3 xsd; do
  %{mvn_install_pom} %{name}-plugins/%{name}-plugin-${i}/pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{name}-plugin-${i}.pom
  %add_maven_depmap %{name}/%{name}-plugin-${i}.pom %{name}/%{name}-plugin-${i}.jar
done

# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}

for i in core; do
  install -dm 0755 %{buildroot}%{_javadocdir}/%{name}/%{name}-${i}
  cp -pr %{name}-${i}/target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/%{name}-${i}/
done

for i in converters dom4j java jdom sax stax xdoc xml xpp3 xsd; do
  install -dm 0755 %{buildroot}%{_javadocdir}/%{name}/%{name}-plugin-${i}
  cp -pr %{name}-plugins/%{name}-plugin-${i}/target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/%{name}-plugin-${i}/
done

%fdupes -s %{buildroot}%{_javadocdir}

# script
%jpackage_script org.codehaus.modello.ModelloCli "" "" modello:org.eclipse.sisu.plexus:org.eclipse.sisu.inject:google-guice:aopalliance:atinject:plexus-containers/plexus-component-annotations:plexus/classworlds:plexus/utils:plexus/plexus-build-api:guava %{name} true

%files -f .mfiles
%license LICENSE
%{_bindir}/*

%files javadoc
%license LICENSE
%{_javadocdir}/%{name}

%changelog
* Mon Sep 11 2023 Fridrich Strba <fstrba@suse.com>
- Cleanup unnecessary dependencies
* Wed Sep  6 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 2.1.2
  * Changes of version 2.1.2
    + Switch to codehaus plexus-build-api 1.2.0 (reverted by a
    patch in this package)
    + Add plexus 13 parent and reformat
    + Remove readonly flag from basedir: support .mdo from any
    location
    + Require Maven 3.5.4+
    + Prepare to run with Java 19+
  * Changes of version 2.1.1
    + replace generatedBy context value by template
    + add velocityBasedir to select where to load (shared) .vm from
  * Changes of version 2.1.0
    + Make the Xpp3Reader#read(XmlPullParser, boolean strict) public
    + Fix json encoding
    + Support arbitrary element names via 'xs:any'
    + Call setter only after object has been populated
    + replace handwritten components.xml with annotations
    + Optionally enforce required elements in XSDs
    + Add a velocity template based generator
    + Use optimised plexus-utils CachingWriter
- Added patch:
  * 0001-Revert-Switch-to-codehaus-plexus-build-api-1.2.0-345.patch
    + use the version of plexus-build-api that we have packaged
- Modified patch:
  * modello-cli-domasxpp3.patch
    + rediff to changed context
* Thu May  4 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add _multibuild to define 2nd spec file as additional flavor.
  Eliminates the need for source package links in OBS.
* Fri May 13 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 2.0.0
  * New features and improvements
    + Add Modello 2.0.0 model XSD
    + Manage xdoc anchor name conflicts (2 classes with same anchor)
    + Drop unnecessary check for identical branches
    + Require Maven 3.1.1
    + Use a caching writer to avoid overwriting identical files
    + Migrate from codehaus:wstx to
    com.fasterxml.woodstox:woodstox-core 6.2.4
    + Make location handling more memory efficient
    + Xpp3 extended writer
    + Refactor some old java APIs usage
    + Add a new field fileComment
  * Bug Fixes
    + Fix javaSource default value
    + Fix modello-plugin-snakeyaml
  * Dependency updates
    + Bump maven-javadoc-plugin from 3.3.1 to 3.3.2
    + Bump release-drafter/release-drafter from 5.17.6 to 5.18.0
    + Bump taglist-maven-plugin from 2.4 to 3.0.0
    + Bump checkstyle from 9.2.1 to 9.3
    + Bump xmlunit-core from 2.8.4 to 2.9.0
    + Bump junit from 4.12 to 4.13.1 in
    /modello-maven-plugin/src/it/maven-model
    + Bump xercesImpl from 2.12.1 to 2.12.2 in
    /modello-plugins/modello-plugin-xsd
    + Bump xercesImpl from 2.12.1 to 2.12.2 in
    /modello-plugins/modello-plugin-jsonschema
    + Bump mavenPluginTools from 3.6.2 to 3.6.4
    + Bump maven-compiler-plugin from 3.8.1 to 3.9.0
    + Bump maven-jar-plugin from 3.2.0 to 3.2.2
    + Bump release-drafter/release-drafter from 5.15.0 to 5.17.6
    + Bump woodstox-core from 6.2.7 to 6.2.8
    + Bump maven-release-plugin from 3.0.0-M4 to 3.0.0-M5
    + Bump checkstyle from 9.2 to 9.2.1
    + Bump maven-site-plugin from 3.9.1 to 3.10.0
    + Bump snakeyaml from 1.29 to 1.30
    + Bump jackson-bom from 2.13.0 to 2.13.1
    + Bump xmlunit-core from 2.8.3 to 2.8.4
    + Bump plexus-compiler-javac from 2.8.8 to 2.9.0
    + Bump woodstox-core from 6.2.6 to 6.2.7
    + Bump maven-shared-resources from 3 to 4
    + Bump plexus-compiler-api from 2.8.8 to 2.9.0
    + Bump mavenPluginTools from 3.6.1 to 3.6.2
    + Bump checkstyle from 9.0.1 to 9.2
    + Bump xmlunit-core from 2.8.2 to 2.8.3
    + Bump checkstyle from 9.0 to 9.0.1
    + Bump checkstyle from 8.45.1 to 9.0
    + Bump jackson-bom from 2.12.5 to 2.13.0
    + Bump org.eclipse.sisu.plexus from 0.3.4 to 0.3.5
    + Bump jsoup from 1.14.2 to 1.14.3
    + Bump actions/setup-java from 2.3.0 to 2.3.1
    + Bump maven-pmd-plugin from 3.14.0 to 3.15.0
    + Bump maven-javadoc-plugin from 3.3.0 to 3.3.1
    + Bump plexus-utils from 3.2.0 to 3.4.1
    + Bump jackson-bom from 2.12.4 to 2.12.5
    + Bump actions/setup-java from 2.2.0 to 2.3.0
    + Bump checkstyle from 8.42 to 8.45.1
    + Bump plexus-velocity from 1.2 to 1.3
    + Bump maven-enforcer-plugin from 3.0.0-M3 to 3.0.0
    + Bump jackson-bom from 2.12.3 to 2.12.4
    + Bump stax2-api from 4.2 to 4.2.1
    + Bump actions/setup-java from 1 to 2.2.0
    + Bump actions/setup-java from 1 to 2.2.0
    + Bump maven-gpg-plugin from 1.6 to 3.0.1
    + Bump woodstox-core from 6.2.4 to 6.2.6
    + Bump maven-dependency-plugin from 3.1.2 to 3.2.0
    + Bump maven-javadoc-plugin from 3.2.0 to 3.3.0
    + Bump snakeyaml from 1.28 to 1.29
    + Bump maven-project-info-reports-plugin from 3.1.1 to 3.1.2
    + Bump actions/cache from 2.1.5 to 2.1.6
    + Bump maven-assembly-plugin from 3.2.0 to 3.3.0
    + Bump maven-jxr-plugin from 3.0.0 to 3.1.1
    + Bump xercesImpl from 2.12.0 to 2.12.1
    + [Snyk] Security upgrade org.jsoup:jsoup from 1.13.1 to 1.14.2
    + Bump actions/checkout from 2 to 2.3.4
    + Bump xmlunit-core from 2.8.1 to 2.8.2
    + Bump maven-surefire-report-plugin from 2.22.1 to 2.22.2
    + Bump maven-scm-publish-plugin from 3.0.0 to 3.1.0
    + Bump snakeyaml from 1.26 to 1.28
    + Bump maven-verifier-plugin from 1.0 to 1.1
    + Bump xml-apis from 1.3.04 to 2.0.2
    + Bump jackson-bom from 2.11.3 to 2.12.3
    + Bump xmlunit from 1.2 to 1.6
    + Bump plexus-compiler-javac from 2.1 to 2.8.8
    + Bump actions/cache from v2.1.4 to v2.1.5
    + Bump release-drafter/release-drafter from v5.12.1 to v5.15.0
    + Bump maven-site-plugin from 3.7.1 to 3.9.1
    + Bump maven-jxr-plugin from 2.5 to 3.0.0
    + Bump actions/cache from v2.1.3 to v2.1.4
    + Bump maven-surefire-plugin from 2.22.1 to 2.22.2
    + Bump plexus-compiler-api from 2.1 to 2.8.8
    + Bump maven-resources-plugin from 3.0.1 to 3.2.0
    + Bump release-drafter/release-drafter from v5.11.0 to v5.12.1
    + Bump xmlunit-core from 2.7.0 to 2.8.1
    + Bump actions/cache from v2.1.2 to v2.1.3
    + Bump jaxb-api from 2.1 to 2.3.1
    + Bump junit from 4.12 to 4.13.1
    + Bump actions/cache from v2.1.0 to v2.1.2
    + Bump maven-checkstyle-plugin from 2.15 to 3.1.1
    + Bump xercesImpl from 2.8.1 to 2.12.0 in
    /modello-plugins/modello-plugin-jsonschema
    + Bump xercesImpl from 2.8.1 to 2.12.0 in
    /modello-plugins/modello-plugin-xsd
    + Bump xercesImpl from 2.8.1 to 2.12.0
    + Bump xmlunit-core from 2.3.0 to 2.7.0
    + Bump snakeyaml from 1.12 to 1.26
    + Bump maven-compiler-plugin from 3.8.0 to 3.8.1
    + Bump maven-dependency-plugin from 2.1 to 3.1.2
    + Bump persistence-api from 1.0 to 1.0.2
    + Bump maven-enforcer-plugin from 3.0.0-M1 to 3.0.0-M3
    + Bump maven-pmd-plugin from 3.11.0 to 3.13.0
    + Bump maven-clean-plugin from 3.0.0 to 3.1.0
  * Documentation updates
    + codehaus is dead
    + remove defunct mailing list info
- Modified patch:
  * Adapt to the change of parameter from useJava5 to javaSource
* Tue Mar 22 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Mon Apr 26 2021 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.11
- Build the jackson and jsonschema plugins too
* Thu Nov 21 2019 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.10.0
- Modified patch:
  * modello-cli-domasxpp3.patch
    + rediff to changed line endings
* Fri Mar 15 2019 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * modello-cli-domasxpp3.patch
    + allow setting on command-line the domAsXpp3 property that
    modello-maven-plugin can set in pom.xml file
* Tue Mar 12 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of modello 1.9.1
- Generate and customize ant build files
